
# Slot: drug




URI: [biolink:drug](https://w3id.org/biolink/vocab/drug)

## Domain and Range

[DrugExposure](DrugExposure.md) ->  <sub>1..*</sub> [ChemicalSubstance](ChemicalSubstance.md)

## Parents


## Children


## Used by

 * [DrugExposure](DrugExposure.md)
